# -*- coding: iso-8859-1 -*-
"""
    MoinMoin redish theme

    @copyright: (c) 2003-2004 by Nir Soffer, Thomas Waldmann, Mauricio Hernandez
    @license: GNU GPL, see COPYING for details.
"""

from MoinMoin.theme import ThemeBase


class Theme(ThemeBase):

    name = "redish"

    stylesheets_print = (
        # theme charset         media       basename
        (name,  'utf-8',   'all',      'common'),
        (name,  'utf-8',   'all',      'print'),
        )
    
    stylesheets_projection = (
        # theme charset         media       basename
        (name,  'utf-8',   'all',      'common'),
        (name,  'utf-8',   'all',      'projection'),
        )
    
    stylesheets = (
        # theme charset         media       basename
        (name,  'utf-8',        'all',      'common'),
        (name,  'utf-8',        'screen',   'screen'),
        (name,  'utf-8',        'print',    'print'),
        (name,  'utf-8',        'projection', 'projection'),
        )

# Public functions #####################################################

    def header(self, d, **kw):
        """ Assemble wiki header
        
        @param d: parameter dictionary
        @rtype: unicode
        @return: page header html
        """
        html = [
            # Pre header custom html
            self.emit_custom_html(self.cfg.page_header1),
            
            # Header
            u'<div id="header">',
            self.logo(),
            self.searchform(d),
            self.username(d),
            self.trail(d),
            self.navibar(d),
            u'<hr id="pageline">',
            self.msg(d),
            self.editbar(d),
            u'</div>',
            
            # Post header custom html (not recommended)
            self.emit_custom_html(self.cfg.page_header2),
            
            # Start of page
            self.startPage(),
            self.title(d),
        ]
        return u'\n'.join(html)

    def footer(self, d, **keywords):
        """ Assemble wiki footer
        
        @param d: parameter dictionary
        @keyword ...:...
        @rtype: unicode
        @return: page footer html
        """
        page = d['page']
        html = [
            # End of page
            self.pageinfo(page),
            self.endPage(),
            
            # Pre footer custom html (not recommended!)
            self.emit_custom_html(self.cfg.page_footer1),
            
            # Footer
            u'<div id="footer">',
            self.editbar(d),
            self.credits(d),
            self.showversion(d, **keywords),
            u'</div>',
            
            # Post footer custom html
            self.emit_custom_html(self.cfg.page_footer2),
            ]
        return u'\n'.join(html)

        
def execute(request):
    """
    Generate and return a theme object
        
    @param request: the request object
    @rtype: MoinTheme
    @return: Theme object
    """
    return Theme(request)

